summaryrefslogtreecommitdiffstats
path: root/tools
diff options
context:
space:
mode:
Diffstat (limited to 'tools')
-rw-r--r--tools/assistant/config.cpp28
-rw-r--r--tools/assistant/helpdialogimpl.cpp4
-rw-r--r--tools/assistant/index.cpp6
-rw-r--r--tools/assistant/main.cpp2
-rw-r--r--tools/assistant/mainwindow.ui.h6
-rw-r--r--tools/assistant/profile.cpp10
-rw-r--r--tools/designer/designer/command.cpp2
-rw-r--r--tools/designer/designer/customwidgeteditorimpl.cpp2
-rw-r--r--tools/designer/designer/hierarchyview.cpp2
-rw-r--r--tools/designer/designer/layout.cpp2
-rw-r--r--tools/designer/designer/mainwindow.cpp6
-rw-r--r--tools/designer/designer/mainwindowactions.cpp2
-rw-r--r--tools/designer/designer/metadatabase.cpp128
-rw-r--r--tools/designer/designer/newformimpl.cpp2
-rw-r--r--tools/designer/designer/pixmapchooser.cpp2
-rw-r--r--tools/designer/designer/project.cpp4
-rw-r--r--tools/designer/designer/propertyeditor.cpp4
-rw-r--r--tools/designer/designer/resource.cpp8
-rw-r--r--tools/designer/designer/wizardeditorimpl.cpp2
-rw-r--r--tools/designer/editor/yyindent.cpp6
-rw-r--r--tools/designer/examples/book/connection.cpp4
-rw-r--r--tools/designer/plugins/cppeditor/yyreg.cpp6
-rw-r--r--tools/designer/plugins/dlg/dlg2ui.cpp2
-rw-r--r--tools/designer/plugins/glade/glade2ui.cpp2
-rw-r--r--tools/designer/plugins/kdevdlg/kdevdlg2ui.cpp4
-rw-r--r--tools/designer/plugins/kdevdlg/main.cpp2
-rw-r--r--tools/designer/plugins/rc/main.cpp2
-rw-r--r--tools/designer/plugins/rc/rc2ui.cpp4
-rw-r--r--tools/designer/tools/conv2ui/main.cpp4
-rw-r--r--tools/designer/uic/embed.cpp2
-rw-r--r--tools/designer/uic/main.cpp10
-rw-r--r--tools/designer/uic/subclassing.cpp2
-rw-r--r--tools/designer/uilib/qwidgetfactory.cpp28
-rw-r--r--tools/linguist/linguist/trwindow.cpp6
-rw-r--r--tools/linguist/lupdate/fetchtr.cpp10
-rw-r--r--tools/makeqpf/main.cpp22
-rw-r--r--tools/mergetr/mergetr.cpp2
-rw-r--r--tools/msg2qm/msg2qm.cpp2
-rw-r--r--tools/qconfig/main.cpp14
-rw-r--r--tools/qembed/qembed.cpp8
-rw-r--r--tools/qvfb/main.cpp2
-rw-r--r--tools/qvfb/qanimationwriter.cpp4
-rw-r--r--tools/qvfb/qvfbview.cpp22
43 files changed, 196 insertions, 196 deletions
diff --git a/tools/assistant/config.cpp b/tools/assistant/config.cpp
index dbc823f..83d0bdc 100644
--- a/tools/assistant/config.cpp
+++ b/tools/assistant/config.cpp
@@ -57,7 +57,7 @@ Config::Config()
if( !static_configuration ) {
static_configuration = this;
} else {
- tqWarning( "Multiple configurations not allowed!" );
+ qWarning( "Multiple configurations not allowed!" );
}
}
@@ -74,23 +74,23 @@ Config *Config::loadConfig(const QString &profileFileName)
QFile file(profileFileName);
if (!file.exists()) {
- tqWarning( "File does not exist: " + profileFileName );
+ qWarning( "File does not exist: " + profileFileName );
return 0;
}
DocuParser *parser = DocuParser::createParser( profileFileName );
if (!parser) {
- tqWarning( "Failed to create parser for file: " + profileFileName );
+ qWarning( "Failed to create parser for file: " + profileFileName );
return 0;
}
if (parser->parserVersion() < DocuParser::Qt320) {
- tqWarning( "File does not contain profile information" );
+ qWarning( "File does not contain profile information" );
return 0;
}
DocuParser320 *profileParser = static_cast<DocuParser320*>(parser);
parser->parse(&file);
config->profil = profileParser->profile();
if (!config->profil) {
- tqWarning( "Config::loadConfig(), no profile in: " + profileFileName );
+ qWarning( "Config::loadConfig(), no profile in: " + profileFileName );
return 0;
}
config->profil->setProfileType(Profile::UserProfile);
@@ -180,10 +180,10 @@ void Config::saveSettings()
#ifdef ASSISTANT_DEBUG
static void dumpmap( const QMap<QString,QString> &m, const QString &header )
{
- tqDebug( header );
+ qDebug( header );
QMap<QString,QString>::ConstIterator it = m.begin();
while (it != m.end()) {
- tqDebug( " " + it.key() + ":\t\t" + *it );
+ qDebug( " " + it.key() + ":\t\t" + *it );
++it;
}
}
@@ -231,7 +231,7 @@ void Config::loadDefaultProfile()
dumpmap( profil->indexPages, "IndexPages" );
dumpmap( profil->imageDirs, "ImageDirs" );
dumpmap( profil->dcfTitles, "dcfTitles" );
- tqDebug( "Docfiles: \n " + profil->docs.join( "\n " ) );
+ qDebug( "Docfiles: \n " + profil->docs.join( "\n " ) );
#endif
}
@@ -264,11 +264,11 @@ void Config::saveProfile( Profile *profile )
settings.writeEntry( profKey + "ImageDirs", imgDirs );
#if ASSISTANT_DEBUG
- tqDebug( "Titles:\n - " + ( (QStringList*) &titles )->join( "\n - " ) );
- tqDebug( "Docfiles:\n - " + dcfs.join( "\n - " ) );
- tqDebug( "IndexPages:\n - " + indexes.join( "\n - " ) );
- tqDebug( "DocIcons:\n - " + icons.join( "\n - " ) );
- tqDebug( "ImageDirs:\n - " + imgDirs.join( "\n - " ) );
+ qDebug( "Titles:\n - " + ( (QStringList*) &titles )->join( "\n - " ) );
+ qDebug( "Docfiles:\n - " + dcfs.join( "\n - " ) );
+ qDebug( "IndexPages:\n - " + indexes.join( "\n - " ) );
+ qDebug( "DocIcons:\n - " + icons.join( "\n - " ) );
+ qDebug( "ImageDirs:\n - " + imgDirs.join( "\n - " ) );
#endif
}
@@ -374,6 +374,6 @@ bool Config::sideBarHidden() const
QString Config::assistantDocPath() const
{
return profil->props["assistantdocs"].isEmpty()
- ? QString( tqInstallPathDocs() ) + "/html"
+ ? QString( qInstallPathDocs() ) + "/html"
: profil->props["assistantdocs"];
}
diff --git a/tools/assistant/helpdialogimpl.cpp b/tools/assistant/helpdialogimpl.cpp
index 45de1d8..ceee175 100644
--- a/tools/assistant/helpdialogimpl.cpp
+++ b/tools/assistant/helpdialogimpl.cpp
@@ -81,7 +81,7 @@ static bool verifyDirectory(const QString &str)
if (!dirInfo.exists())
return QDir().mkdir(str);
if (!dirInfo.isDir()) {
- tqWarning("'%s' exists but is not a directory", str.latin1());
+ qWarning("'%s' exists but is not a directory", str.latin1());
return FALSE;
}
return TRUE;
@@ -268,7 +268,7 @@ void HelpDialog::removeOldCacheFiles()
{
QString dir = cacheFilesPath; // ### remove the last '/' ?
if (!verifyDirectory(cacheFilesPath)) {
- tqWarning( "Failed to created assistant directory" );
+ qWarning( "Failed to created assistant directory" );
return;
}
QString pname = "." + Config::configuration()->profileName();
diff --git a/tools/assistant/index.cpp b/tools/assistant/index.cpp
index c2190e6..9e73ceb 100644
--- a/tools/assistant/index.cpp
+++ b/tools/assistant/index.cpp
@@ -158,7 +158,7 @@ void Index::parseDocument( const QString &filename, int docNum )
{
QFile file( filename );
if ( !file.open( IO_ReadOnly ) ) {
- tqWarning( "can not open file " + filename );
+ qWarning( "can not open file " + filename );
return;
}
@@ -327,7 +327,7 @@ QString Index::getDocumentTitle( const QString &fileName )
{
QFile file( fileName );
if ( !file.open( IO_ReadOnly ) ) {
- tqWarning( "cannot open file " + fileName );
+ qWarning( "cannot open file " + fileName );
return fileName;
}
QTextStream s( &file );
@@ -450,7 +450,7 @@ bool Index::searchForPattern( const QStringList &patterns, const QStringList &wo
{
QFile file( fileName );
if ( !file.open( IO_ReadOnly ) ) {
- tqWarning( "cannot open file " + fileName );
+ qWarning( "cannot open file " + fileName );
return FALSE;
}
diff --git a/tools/assistant/main.cpp b/tools/assistant/main.cpp
index aa5f3be..0619909 100644
--- a/tools/assistant/main.cpp
+++ b/tools/assistant/main.cpp
@@ -286,7 +286,7 @@ int main( int argc, char ** argv )
}
if( resourceDir.isNull() )
- resourceDir = tqInstallPathTranslations();
+ resourceDir = qInstallPathTranslations();
QTranslator translator( 0 );
translator.load( QString("assistant_") + QTextCodec::locale(), resourceDir );
diff --git a/tools/assistant/mainwindow.ui.h b/tools/assistant/mainwindow.ui.h
index e5df018..75acd89 100644
--- a/tools/assistant/mainwindow.ui.h
+++ b/tools/assistant/mainwindow.ui.h
@@ -412,7 +412,7 @@ void MainWindow::showLinkFromClient( const QString &link )
void MainWindow::showLink( const QString &link )
{
if( link.isEmpty() ) {
- tqWarning( "The link is empty!" );
+ qWarning( "The link is empty!" );
}
int find = link.find( '#' );
@@ -441,7 +441,7 @@ void MainWindow::showLink( const QString &link )
void MainWindow::showLinks( const QStringList &links )
{
if ( links.size() == 0 ) {
- tqWarning( "MainWindow::showLinks() - Empty link" );
+ qWarning( "MainWindow::showLinks() - Empty link" );
return;
}
@@ -482,7 +482,7 @@ void MainWindow::timerEvent(QTimerEvent *e)
void MainWindow::showQtHelp()
{
- showLink( QString( tqInstallPathDocs() ) + "/html/index.html" );
+ showLink( QString( qInstallPathDocs() ) + "/html/index.html" );
}
void MainWindow::showSettingsDialog()
diff --git a/tools/assistant/profile.cpp b/tools/assistant/profile.cpp
index 8d65754..be83f2a 100644
--- a/tools/assistant/profile.cpp
+++ b/tools/assistant/profile.cpp
@@ -45,7 +45,7 @@
Profile *Profile::createDefaultProfile( const QString &docPath )
{
- QString path = tqInstallPathDocs();
+ QString path = qInstallPathDocs();
if ( !docPath.isEmpty() )
path = docPath;
path = path + "/html/";
@@ -116,9 +116,9 @@ void Profile::removeDocFileEntry( const QString &docfile )
}
#ifdef ASSISTANT_DEBUG
- tqDebug( "docs:\n - " + docs.join( "\n - " ) );
- tqDebug( "titles:\n - " + titles.join( "\n - " ) );
- tqDebug( "keys:\n - " + ( (QStringList*) &(dcfTitles.keys()) )->join( "\n - " ) );
- tqDebug( "values:\n - " + ( (QStringList*) &(dcfTitles.values()) )->join( "\n - " ) );
+ qDebug( "docs:\n - " + docs.join( "\n - " ) );
+ qDebug( "titles:\n - " + titles.join( "\n - " ) );
+ qDebug( "keys:\n - " + ( (QStringList*) &(dcfTitles.keys()) )->join( "\n - " ) );
+ qDebug( "values:\n - " + ( (QStringList*) &(dcfTitles.values()) )->join( "\n - " ) );
#endif
}
diff --git a/tools/designer/designer/command.cpp b/tools/designer/designer/command.cpp
index b12a598..74a6b19 100644
--- a/tools/designer/designer/command.cpp
+++ b/tools/designer/designer/command.cpp
@@ -2220,7 +2220,7 @@ void AddMenuCommand::execute()
void AddMenuCommand::unexecute()
{
if ( !item ) {
- tqWarning( "The AddMenuCommand was created without a menu item." );
+ qWarning( "The AddMenuCommand was created without a menu item." );
return;
}
item->menu()->hide();
diff --git a/tools/designer/designer/customwidgeteditorimpl.cpp b/tools/designer/designer/customwidgeteditorimpl.cpp
index 6991fab..412f50f 100644
--- a/tools/designer/designer/customwidgeteditorimpl.cpp
+++ b/tools/designer/designer/customwidgeteditorimpl.cpp
@@ -764,7 +764,7 @@ void CustomWidgetEditor::loadDescription()
QString errMsg;
int errLine;
if ( !doc.setContent( &f, &errMsg, &errLine ) ) {
- tqDebug( QString("Parse error: ") + errMsg + QString(" in line %d"), errLine );
+ qDebug( QString("Parse error: ") + errMsg + QString(" in line %d"), errLine );
return;
}
diff --git a/tools/designer/designer/hierarchyview.cpp b/tools/designer/designer/hierarchyview.cpp
index 7e78580..b4c68cc 100644
--- a/tools/designer/designer/hierarchyview.cpp
+++ b/tools/designer/designer/hierarchyview.cpp
@@ -911,7 +911,7 @@ static HierarchyItem::Type getChildType( int type )
{
switch ( (HierarchyItem::Type)type ) {
case HierarchyItem::Widget:
- tqWarning( "getChildType: Inserting childs dynamically to Widget or SlotParent is not allowed!" );
+ qWarning( "getChildType: Inserting childs dynamically to Widget or SlotParent is not allowed!" );
break;
case HierarchyItem::SlotParent:
case HierarchyItem::SlotPublic:
diff --git a/tools/designer/designer/layout.cpp b/tools/designer/designer/layout.cpp
index 3efe107..2701023 100644
--- a/tools/designer/designer/layout.cpp
+++ b/tools/designer/designer/layout.cpp
@@ -774,7 +774,7 @@ void GridLayout::doLayout()
( (QLayoutWidget*)w )->updateSizePolicy();
w->show();
} else {
- tqWarning("ooops, widget '%s' does not fit in layout", w->name() );
+ qWarning("ooops, widget '%s' does not fit in layout", w->name() );
}
}
finishLayout( needMove, layout );
diff --git a/tools/designer/designer/mainwindow.cpp b/tools/designer/designer/mainwindow.cpp
index 3bdf654..0474b2f 100644
--- a/tools/designer/designer/mainwindow.cpp
+++ b/tools/designer/designer/mainwindow.cpp
@@ -133,7 +133,7 @@ MainWindow *MainWindow::self = 0;
QString assistantPath()
{
- QString path = QDir::cleanDirPath( QString( tqInstallPathBins() ) +
+ QString path = QDir::cleanDirPath( QString( qInstallPathBins() ) +
QDir::separator() );
return path;
}
@@ -2794,7 +2794,7 @@ void MainWindow::setSnapGrid( bool b )
QString MainWindow::documentationPath() const
{
- return QString( tqInstallPathDocs() ) + "/html/";
+ return QString( qInstallPathDocs() ) + "/html/";
}
void MainWindow::windowsMenuActivated( int id )
@@ -3421,7 +3421,7 @@ void MainWindow::showSourceLine( QObject *o, int line, LineMode lm )
fw = ff->formWindow();
if ( !fw && !qwf_forms ) {
- tqWarning( "MainWindow::showSourceLine: qwf_forms is NULL!" );
+ qWarning( "MainWindow::showSourceLine: qwf_forms is NULL!" );
return;
}
diff --git a/tools/designer/designer/mainwindowactions.cpp b/tools/designer/designer/mainwindowactions.cpp
index c847f92..d8d99aa 100644
--- a/tools/designer/designer/mainwindowactions.cpp
+++ b/tools/designer/designer/mainwindowactions.cpp
@@ -1450,7 +1450,7 @@ void MainWindow::createNewTemplate()
const char *qtdir = getenv( "QTDIR" );
if(qtdir)
templRoots << qtdir;
- templRoots << tqInstallPathData();
+ templRoots << qInstallPathData();
if(qtdir) //try the tools/designer directory last!
templRoots << (QString(qtdir) + "/tools/designer");
QFile f;
diff --git a/tools/designer/designer/metadatabase.cpp b/tools/designer/designer/metadatabase.cpp
index 4da93cc..cd36cc0 100644
--- a/tools/designer/designer/metadatabase.cpp
+++ b/tools/designer/designer/metadatabase.cpp
@@ -152,7 +152,7 @@ void MetaDataBase::setPropertyChanged( QObject *o, const QString &property, bool
}
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -191,7 +191,7 @@ bool MetaDataBase::isPropertyChanged( QObject *o, const QString &property )
return ( (PropertyObject*)o )->mdIsPropertyChanged( property );
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return FALSE;
}
@@ -204,7 +204,7 @@ QStringList MetaDataBase::changedProperties( QObject *o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QStringList();
}
@@ -222,7 +222,7 @@ void MetaDataBase::setPropertyComment( QObject *o, const QString &property, cons
}
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -237,7 +237,7 @@ QString MetaDataBase::propertyComment( QObject *o, const QString &property )
return ( (PropertyObject*)o )->mdPropertyComment( property );
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QString::null;
}
@@ -254,7 +254,7 @@ void MetaDataBase::setFakeProperty( QObject *o, const QString &property, const Q
}
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -268,7 +268,7 @@ QVariant MetaDataBase::fakeProperty( QObject * o, const QString &property)
return ( (PropertyObject*)o )->mdFakeProperty( property );
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QVariant();
}
@@ -284,7 +284,7 @@ QMap<QString,QVariant>* MetaDataBase::fakeProperties( QObject* o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return 0;
}
@@ -298,7 +298,7 @@ void MetaDataBase::setSpacing( QObject *o, int spacing )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r || !o->isWidgetType() ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -326,7 +326,7 @@ int MetaDataBase::spacing( QObject *o )
o = ( (QMainWindow*)o )->centralWidget();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r || !o->isWidgetType() ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return -1;
}
@@ -341,7 +341,7 @@ void MetaDataBase::setMargin( QObject *o, int margin )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r || !o->isWidgetType() ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -383,7 +383,7 @@ int MetaDataBase::margin( QObject *o )
o = ( (QMainWindow*)o )->centralWidget();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r || !o->isWidgetType() ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return -1;
}
@@ -397,7 +397,7 @@ void MetaDataBase::setResizeMode( QObject *o, const QString &mode )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r || !o->isWidgetType() ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -414,7 +414,7 @@ QString MetaDataBase::resizeMode( QObject *o )
o = ( (QMainWindow*)o )->centralWidget();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r || !o->isWidgetType() ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QString::null;
}
@@ -427,7 +427,7 @@ void MetaDataBase::addConnection( QObject *o, QObject *sender, const QCString &s
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -461,7 +461,7 @@ void MetaDataBase::removeConnection( QObject *o, QObject *sender, const QCString
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -490,7 +490,7 @@ void MetaDataBase::setupConnections( QObject *o, const QValueList<LanguageInterf
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -538,7 +538,7 @@ bool MetaDataBase::hasConnection( QObject *o, QObject *sender, const QCString &s
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return FALSE;
}
@@ -560,7 +560,7 @@ QValueList<MetaDataBase::Connection> MetaDataBase::connections( QObject *o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QValueList<Connection>();
}
@@ -573,7 +573,7 @@ QValueList<MetaDataBase::Connection> MetaDataBase::connections( QObject *o, QObj
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QValueList<Connection>();
}
@@ -595,7 +595,7 @@ QValueList<MetaDataBase::Connection> MetaDataBase::connections( QObject *o, QObj
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QValueList<Connection>();
}
@@ -616,7 +616,7 @@ void MetaDataBase::doConnections( QObject *o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -670,7 +670,7 @@ bool MetaDataBase::hasSlot( QObject *o, const QCString &slot, bool onlyCustom )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return FALSE;
}
@@ -714,7 +714,7 @@ bool MetaDataBase::isSlotUsed( QObject *o, const QCString &slot )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return FALSE;
}
@@ -735,7 +735,7 @@ void MetaDataBase::addFunction( QObject *o, const QCString &function, const QStr
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -759,7 +759,7 @@ void MetaDataBase::setFunctionList( QObject *o, const QValueList<Function> &func
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -773,7 +773,7 @@ void MetaDataBase::removeFunction( QObject *o, const QCString &function, const Q
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -797,7 +797,7 @@ void MetaDataBase::removeFunction( QObject *o, const QString &function )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -815,7 +815,7 @@ QValueList<MetaDataBase::Function> MetaDataBase::functionList( QObject *o, bool
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QValueList<Function>();
}
@@ -834,7 +834,7 @@ QValueList<MetaDataBase::Function> MetaDataBase::slotList( QObject *o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QValueList<Function>();
}
@@ -852,7 +852,7 @@ void MetaDataBase::changeFunction( QObject *o, const QString &function, const QS
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -876,7 +876,7 @@ void MetaDataBase::changeFunctionAttributes( QObject *o, const QString &oldName,
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -900,7 +900,7 @@ bool MetaDataBase::hasFunction( QObject *o, const QCString &function, bool onlyC
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return FALSE;
}
@@ -944,7 +944,7 @@ QString MetaDataBase::languageOfFunction( QObject *o, const QCString &function )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QString::null;
}
@@ -1038,7 +1038,7 @@ void MetaDataBase::setTabOrder( QWidget *w, const QWidgetList &order )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*) w );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
w, w->name(), w->className() );
return;
}
@@ -1051,7 +1051,7 @@ QWidgetList MetaDataBase::tabOrder( QWidget *w )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*) w );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
w, w->name(), w->className() );
return QWidgetList();
}
@@ -1064,7 +1064,7 @@ void MetaDataBase::setIncludes( QObject *o, const QValueList<Include> &incs )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1077,7 +1077,7 @@ QValueList<MetaDataBase::Include> MetaDataBase::includes( QObject *o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QValueList<Include>();
}
@@ -1090,7 +1090,7 @@ void MetaDataBase::setForwards( QObject *o, const QStringList &fwds )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1103,7 +1103,7 @@ QStringList MetaDataBase::forwards( QObject *o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QStringList();
}
@@ -1116,7 +1116,7 @@ void MetaDataBase::setVariables( QObject *o, const QValueList<Variable> &vars )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1129,7 +1129,7 @@ void MetaDataBase::addVariable( QObject *o, const QString &name, const QString &
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1144,7 +1144,7 @@ void MetaDataBase::removeVariable( QObject *o, const QString &name )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1162,7 +1162,7 @@ QValueList<MetaDataBase::Variable> MetaDataBase::variables( QObject *o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QValueList<MetaDataBase::Variable>();
}
@@ -1175,7 +1175,7 @@ bool MetaDataBase::hasVariable( QObject *o, const QString &name )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return FALSE;
}
@@ -1203,7 +1203,7 @@ void MetaDataBase::setSignalList( QObject *o, const QStringList &sigs )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1236,7 +1236,7 @@ QStringList MetaDataBase::signalList( QObject *o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QStringList();
}
@@ -1249,7 +1249,7 @@ void MetaDataBase::setMetaInfo( QObject *o, MetaInfo mi )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1262,7 +1262,7 @@ MetaDataBase::MetaInfo MetaDataBase::metaInfo( QObject *o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return MetaInfo();
}
@@ -1308,7 +1308,7 @@ void MetaDataBase::setCursor( QWidget *w, const QCursor &c )
}
MetaDataBaseRecord *r = db->find( (void*)w );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
w, w->name(), w->className() );
return;
}
@@ -1399,7 +1399,7 @@ void MetaDataBase::setPixmapArgument( QObject *o, int pixmap, const QString &arg
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1415,7 +1415,7 @@ QString MetaDataBase::pixmapArgument( QObject *o, int pixmap )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QString::null;
}
@@ -1430,7 +1430,7 @@ void MetaDataBase::clearPixmapArguments( QObject *o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1450,7 +1450,7 @@ void MetaDataBase::setPixmapKey( QObject *o, int pixmap, const QString &arg )
}
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1468,7 +1468,7 @@ QString MetaDataBase::pixmapKey( QObject *o, int pixmap )
return ( (PropertyObject*)o )->mdPixmapKey( pixmap );
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QString::null;
}
@@ -1491,7 +1491,7 @@ void MetaDataBase::clearPixmapKeys( QObject *o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1508,7 +1508,7 @@ void MetaDataBase::setColumnFields( QObject *o, const QMap<QString, QString> &co
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1523,7 +1523,7 @@ QMap<QString, QString> MetaDataBase::columnFields( QObject *o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QMap<QString, QString>();
}
@@ -1589,7 +1589,7 @@ void MetaDataBase::setBreakPoints( QObject *o, const QValueList<uint> &l )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1612,7 +1612,7 @@ QValueList<uint> MetaDataBase::breakPoints( QObject *o )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QValueList<uint>();
}
@@ -1627,7 +1627,7 @@ void MetaDataBase::setBreakPointCondition( QObject *o, int line, const QString &
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1641,7 +1641,7 @@ QString MetaDataBase::breakPointCondition( QObject *o, int line )
setupDataBase();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return QString::null;
}
@@ -1662,7 +1662,7 @@ void MetaDataBase::setExportMacro( QObject *o, const QString &macro )
}
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return;
}
@@ -1679,7 +1679,7 @@ QString MetaDataBase::exportMacro( QObject *o )
return ( (PropertyObject*)o )->mdExportMacro();
MetaDataBaseRecord *r = db->find( (void*)o );
if ( !r ) {
- tqWarning( "No entry for %p (%s, %s) found in MetaDataBase",
+ qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
o, o->name(), o->className() );
return "";
}
diff --git a/tools/designer/designer/newformimpl.cpp b/tools/designer/designer/newformimpl.cpp
index 8ef429c..a4a6ce0 100644
--- a/tools/designer/designer/newformimpl.cpp
+++ b/tools/designer/designer/newformimpl.cpp
@@ -289,7 +289,7 @@ void NewForm::insertTemplates( QIconView *tView,
const char *qtdir = getenv( "QTDIR" );
if(qtdir)
templRoots << qtdir;
- templRoots << tqInstallPathData();
+ templRoots << qInstallPathData();
if(qtdir) //try the tools/designer directory last!
templRoots << (QString(qtdir) + "/tools/designer");
for ( QStringList::Iterator it = templRoots.begin(); it != templRoots.end(); ++it ) {
diff --git a/tools/designer/designer/pixmapchooser.cpp b/tools/designer/designer/pixmapchooser.cpp
index 9e64053..8c8b0a7 100644
--- a/tools/designer/designer/pixmapchooser.cpp
+++ b/tools/designer/designer/pixmapchooser.cpp
@@ -83,7 +83,7 @@ void PixmapView::previewUrl( const QUrl &u )
if ( !pix.isNull() )
setPixmap( pix );
} else {
- tqWarning( "Previewing remote files not supported." );
+ qWarning( "Previewing remote files not supported." );
}
}
diff --git a/tools/designer/designer/project.cpp b/tools/designer/designer/project.cpp
index 6f97dd8..3eae1c4 100644
--- a/tools/designer/designer/project.cpp
+++ b/tools/designer/designer/project.cpp
@@ -1048,7 +1048,7 @@ void Project::loadConnections()
dbConnections.append( conn );
}
} else {
- tqDebug( QString("Parse error: ") + errMsg + QString(" in line %d"), errLine );
+ qDebug( QString("Parse error: ") + errMsg + QString(" in line %d"), errLine );
}
f.close();
}
@@ -1583,7 +1583,7 @@ QString Project::locationOfObject( QObject *o )
extern QMap<QWidget*, QString> *qwf_forms;
if ( !qwf_forms ) {
- tqWarning( "Project::locationOfObject: qwf_forms is NULL!" );
+ qWarning( "Project::locationOfObject: qwf_forms is NULL!" );
return QString::null;
}
diff --git a/tools/designer/designer/propertyeditor.cpp b/tools/designer/designer/propertyeditor.cpp
index c0c89ae..708f779 100644
--- a/tools/designer/designer/propertyeditor.cpp
+++ b/tools/designer/designer/propertyeditor.cpp
@@ -118,7 +118,7 @@ static QStringList getFontList()
{
if ( !fontDataBase ) {
fontDataBase = new QFontDatabase;
- tqAddPostRoutine( cleanupFontDatabase );
+ qAddPostRoutine( cleanupFontDatabase );
}
return fontDataBase->families();
}
@@ -150,7 +150,7 @@ bool PropertyWhatsThis::clicked( const QString& href )
{
if ( !href.isEmpty() ) {
QAssistantClient *ac = MainWindow::self->assistantClient();
- ac->showPage( QString( tqInstallPathDocs() ) + "/html/" + href );
+ ac->showPage( QString( qInstallPathDocs() ) + "/html/" + href );
}
return FALSE; // do not hide window
}
diff --git a/tools/designer/designer/wizardeditorimpl.cpp b/tools/designer/designer/wizardeditorimpl.cpp
index 7e3cff1..8754953 100644
--- a/tools/designer/designer/wizardeditorimpl.cpp
+++ b/tools/designer/designer/wizardeditorimpl.cpp
@@ -252,7 +252,7 @@ void WizardEditor::itemDropped( QListBoxItem * i )
// Assumes that only one item has been moved.
int droppedItem = listBox->index( i );
- //tqDebug( "Moving page %d -> %d", draggedItem, droppedItem );
+ //qDebug( "Moving page %d -> %d", draggedItem, droppedItem );
MoveWizardPageCommand *cmd = new MoveWizardPageCommand( tr( "Move page %1 to %2 in %3" ).arg( draggedItem ).arg( droppedItem ).arg( wizard->name() ), formwindow, wizard, draggedItem, droppedItem );
commands.append( cmd );
}
diff --git a/tools/designer/editor/yyindent.cpp b/tools/designer/editor/yyindent.cpp
index 3493dac..df9a78f 100644
--- a/tools/designer/editor/yyindent.cpp
+++ b/tools/designer/editor/yyindent.cpp
@@ -1115,7 +1115,7 @@ static QString fileContents( const QString& fileName )
{
QFile f( fileName );
if ( !f.open(IO_ReadOnly) ) {
- tqWarning( "yyindent error: Cannot open file '%s' for reading: %s",
+ qWarning( "yyindent error: Cannot open file '%s' for reading: %s",
fileName.latin1(), strerror(errno) );
return QString::null;
}
@@ -1124,14 +1124,14 @@ static QString fileContents( const QString& fileName )
QString contents = t.read();
f.close();
if ( contents.isEmpty() )
- tqWarning( "yyindent error: File '%s' is empty", fileName.latin1() );
+ qWarning( "yyindent error: File '%s' is empty", fileName.latin1() );
return contents;
}
int main( int argc, char **argv )
{
if ( argc != 2 ) {
- tqWarning( "usage: yyindent file.cpp" );
+ qWarning( "usage: yyindent file.cpp" );
return 1;
}
diff --git a/tools/designer/examples/book/connection.cpp b/tools/designer/examples/book/connection.cpp
index 9bd0a45..710f50c 100644
--- a/tools/designer/examples/book/connection.cpp
+++ b/tools/designer/examples/book/connection.cpp
@@ -18,9 +18,9 @@ bool createConnections()
defaultDB->setPassword( DB_BOOKS_PASSWD );
defaultDB->setHostName( DB_BOOKS_HOST );
if ( ! defaultDB->open() ) {
- tqWarning( "Failed to open books database: " +
+ qWarning( "Failed to open books database: " +
defaultDB->lastError().driverText() );
- tqWarning( defaultDB->lastError().databaseText() );
+ qWarning( defaultDB->lastError().databaseText() );
return FALSE;
}
diff --git a/tools/designer/plugins/dlg/dlg2ui.cpp b/tools/designer/plugins/dlg/dlg2ui.cpp
index 66a485a..c309eb2 100644
--- a/tools/designer/plugins/dlg/dlg2ui.cpp
+++ b/tools/designer/plugins/dlg/dlg2ui.cpp
@@ -1617,7 +1617,7 @@ QStringList Dlg2Ui::convertQtArchitectDlgFile( const QString& fileName )
outf.setName( outFileName );
if ( !outf.open(IO_WriteOnly) ) {
- tqWarning( "dlg2ui: Could not open output file '%s'",
+ qWarning( "dlg2ui: Could not open output file '%s'",
outFileName.latin1() );
return QStringList();
}
diff --git a/tools/designer/plugins/glade/glade2ui.cpp b/tools/designer/plugins/glade/glade2ui.cpp
index 07efef2..39ff5e8 100644
--- a/tools/designer/plugins/glade/glade2ui.cpp
+++ b/tools/designer/plugins/glade/glade2ui.cpp
@@ -2181,7 +2181,7 @@ QStringList Glade2Ui::convertGladeFile( const QString& fileName )
outFileName += QString( ".ui" );
FILE *out = fopen( outFileName.latin1(), "w" );
if ( out == 0 ) {
- tqWarning( "glade2ui: Could not open file '%s'",
+ qWarning( "glade2ui: Could not open file '%s'",
outFileName.latin1() );
} else {
if ( !yyOut.isEmpty() )
diff --git a/tools/designer/plugins/kdevdlg/kdevdlg2ui.cpp b/tools/designer/plugins/kdevdlg/kdevdlg2ui.cpp
index 2934612..bce7fb2 100644
--- a/tools/designer/plugins/kdevdlg/kdevdlg2ui.cpp
+++ b/tools/designer/plugins/kdevdlg/kdevdlg2ui.cpp
@@ -251,7 +251,7 @@ bool KDEVDLG2UI::parse()
QString outputFile = QString( className ) + ".ui";
fileOut.setName( outputFile );
if (!fileOut.open( IO_WriteOnly ) )
- tqFatal( "kdevdlg2ui: Could not open output file '%s'", outputFile.latin1() );
+ qFatal( "kdevdlg2ui: Could not open output file '%s'", outputFile.latin1() );
out = new QTextStream( &fileOut );
targetFiles.append( outputFile );
} else {
@@ -515,7 +515,7 @@ bool KDEVDLG2UI::writeDialog( const QString& name )
writeColor( "paletteBackgroundColor", color );
} //else {
//if ( line.length() )
- //tqDebug( "IGNORED: %s", line.latin1() );
+ //qDebug( "IGNORED: %s", line.latin1() );
//}
}
*out << "</UI>" << endl;
diff --git a/tools/designer/plugins/kdevdlg/main.cpp b/tools/designer/plugins/kdevdlg/main.cpp
index 6011ca0..1247f3d 100644
--- a/tools/designer/plugins/kdevdlg/main.cpp
+++ b/tools/designer/plugins/kdevdlg/main.cpp
@@ -89,7 +89,7 @@ QStringList KDevDlgFilter::import( const QString &, const QString& filename )
{
QFile file( filename );
if ( !file.open( IO_ReadOnly ) )
- tqWarning( "uic: Could not open file '%s' ", filename.latin1() );
+ qWarning( "uic: Could not open file '%s' ", filename.latin1() );
QTextStream in;
in.setDevice( &file );
diff --git a/tools/designer/plugins/rc/main.cpp b/tools/designer/plugins/rc/main.cpp
index b3900a9..f2e9abb 100644
--- a/tools/designer/plugins/rc/main.cpp
+++ b/tools/designer/plugins/rc/main.cpp
@@ -87,7 +87,7 @@ QStringList RCFilter::import( const QString &, const QString& filename )
{
QFile file( filename );
if ( !file.open( IO_ReadOnly ) )
- tqWarning( "uic: Could not open file '%s' ", filename.latin1() );
+ qWarning( "uic: Could not open file '%s' ", filename.latin1() );
QTextStream in;
in.setDevice( &file );
diff --git a/tools/designer/plugins/rc/rc2ui.cpp b/tools/designer/plugins/rc/rc2ui.cpp
index 0f27730..b3e48dd 100644
--- a/tools/designer/plugins/rc/rc2ui.cpp
+++ b/tools/designer/plugins/rc/rc2ui.cpp
@@ -380,7 +380,7 @@ bool RC2UI::makeDialog()
QString outputFile = QString(className) + ".ui";
fileOut.setName( outputFile );
if (!fileOut.open( IO_WriteOnly ) )
- tqFatal( "rc2ui: Could not open output file '%s'", outputFile.latin1() );
+ qFatal( "rc2ui: Could not open output file '%s'", outputFile.latin1() );
out = new QTextStream( &fileOut );
targetFiles.append( outputFile );
} else {
@@ -838,7 +838,7 @@ bool RC2UI::makeStringTable()
if (outputFile ) {
fileOut.setName( outputFile );
if (!fileOut.open( IO_WriteOnly ) )
- tqFatal( "rc2ui: Could not open output file '%s'", outputFile.latin1() );
+ qFatal( "rc2ui: Could not open output file '%s'", outputFile.latin1() );
out = new QTextStream( &fileOut );
}
diff --git a/tools/designer/tools/conv2ui/main.cpp b/tools/designer/tools/conv2ui/main.cpp
index f0c32c5..7ede6c7 100644
--- a/tools/designer/tools/conv2ui/main.cpp
+++ b/tools/designer/tools/conv2ui/main.cpp
@@ -76,12 +76,12 @@ bool Conv2ui::reinit()
bool Conv2ui::convert( const QString & filename, const QDir & dest )
{
if ( !importFiltersManager ) {
- tqWarning( "Conv2ui: no QPluginManager was found" );
+ qWarning( "Conv2ui: no QPluginManager was found" );
return FALSE;
}
if ( !QFile::exists( absName( filename ) ) ) {
- tqWarning( "Conv2ui: can not find file %s", filename.latin1() );
+ qWarning( "Conv2ui: can not find file %s", filename.latin1() );
return FALSE;
}
diff --git a/tools/designer/uic/embed.cpp b/tools/designer/uic/embed.cpp
index 6ac2885..f6f09c4 100644
--- a/tools/designer/uic/embed.cpp
+++ b/tools/designer/uic/embed.cpp
@@ -78,7 +78,7 @@ static QString convertToCIdentifier( const char *s )
static ulong embedData( QTextStream& out, const uchar* input, int nbytes )
{
#ifndef QT_NO_IMAGE_COLLECTION_COMPRESSION
- QByteArray bazip( tqCompress( input, nbytes ) );
+ QByteArray bazip( qCompress( input, nbytes ) );
ulong len = bazip.size();
#else
ulong len = nbytes;
diff --git a/tools/designer/uic/main.cpp b/tools/designer/uic/main.cpp
index 6a8db05..ace2033 100644
--- a/tools/designer/uic/main.cpp
+++ b/tools/designer/uic/main.cpp
@@ -265,7 +265,7 @@ int main( int argc, char * argv[] )
if ( !outputFile.isEmpty() ) {
fileOut.setName( outputFile );
if (!fileOut.open( IO_WriteOnly ) ) {
- tqWarning( "uic: Could not open output file '%s'", outputFile.data() );
+ qWarning( "uic: Could not open output file '%s'", outputFile.data() );
return 1;
}
} else {
@@ -283,7 +283,7 @@ int main( int argc, char * argv[] )
QFile file( fileName );
if ( !file.open( IO_ReadOnly ) ) {
- tqWarning( "uic: Could not open file '%s'", fileName );
+ qWarning( "uic: Could not open file '%s'", fileName );
return 1;
}
@@ -291,13 +291,13 @@ int main( int argc, char * argv[] )
QString errMsg;
int errLine;
if ( !doc.setContent( &file, &errMsg, &errLine ) ) {
- tqWarning( QString("uic: Failed to parse %s: ") + errMsg + QString (" in line %d"), fileName, errLine );
+ qWarning( QString("uic: Failed to parse %s: ") + errMsg + QString (" in line %d"), fileName, errLine );
return 1;
}
QDomElement e = doc.firstChild().toElement();
if ( e.hasAttribute("version") && e.attribute("version").toDouble() > 3.3 ) {
- tqWarning( QString("uic: File generated with too recent version of Qt Designer (%s vs. %s)"),
+ qWarning( QString("uic: File generated with too recent version of Qt Designer (%s vs. %s)"),
e.attribute("version").latin1(), QT_VERSION_STR );
return 1;
}
@@ -350,7 +350,7 @@ int main( int argc, char * argv[] )
out << "#endif // " << protector << endl;
}
if ( fileOut.status() != IO_Ok ) {
- tqWarning( "uic: Error writing to file" );
+ qWarning( "uic: Error writing to file" );
if ( !outputFile.isEmpty() )
remove( outputFile );
}
diff --git a/tools/designer/uic/subclassing.cpp b/tools/designer/uic/subclassing.cpp
index 4b0b16c..a7be6df 100644
--- a/tools/designer/uic/subclassing.cpp
+++ b/tools/designer/uic/subclassing.cpp
@@ -345,7 +345,7 @@ void Uic::writeFunctionsSubImpl( const QStringList &fuLst, const QStringList &ty
out << " */" << endl;
out << type << " " << subClass << "::" << (*it) << endl;
out << "{" << endl;
- out << " tqWarning( \"" << subClass << "::" << (*it) << " not yet implemented!\" );" << endl;
+ out << " qWarning( \"" << subClass << "::" << (*it) << " not yet implemented!\" );" << endl;
out << "}" << endl << endl;
}
out << endl;
diff --git a/tools/designer/uilib/qwidgetfactory.cpp b/tools/designer/uilib/qwidgetfactory.cpp
index 0340bc8..b7fc6e9 100644
--- a/tools/designer/uilib/qwidgetfactory.cpp
+++ b/tools/designer/uilib/qwidgetfactory.cpp
@@ -344,7 +344,7 @@ QWidget *QWidgetFactory::create( QIODevice *dev, QObject *connector, QWidget *pa
if ( doc.setContent( dev, &errMsg, &errLine ) ) {
w = widgetFactory->createFromUiFile( doc, connector, parent, name );
} else {
- // tqDebug( QString("Parse error: ") + errMsg + QString(" in line %d"), errLine );
+ // qDebug( QString("Parse error: ") + errMsg + QString(" in line %d"), errLine );
}
}
if ( !w ) {
@@ -701,7 +701,7 @@ void QWidgetFactory::inputSpacer( const UibStrTable& strings, QDataStream& in,
}
break;
default:
- tqFatal( "Corrupt" );
+ qFatal( "Corrupt" );
}
in >> objectTag;
}
@@ -768,7 +768,7 @@ void QWidgetFactory::inputColumnOrRow( const UibStrTable& strings,
}
break;
default:
- tqFatal( "Corrupt" );
+ qFatal( "Corrupt" );
}
in >> objectTag;
}
@@ -833,7 +833,7 @@ void QWidgetFactory::inputItem( const UibStrTable& strings, QDataStream& in,
pixmaps << value.asPixmap();
break;
default:
- tqFatal( "Corrupt" );
+ qFatal( "Corrupt" );
}
in >> objectTag;
}
@@ -904,7 +904,7 @@ void QWidgetFactory::inputMenuItem( QObject **objects,
popupMenu->insertSeparator();
break;
default:
- tqFatal( "Corrupt" );
+ qFatal( "Corrupt" );
}
in >> objectTag;
}
@@ -1091,7 +1091,7 @@ QObject *QWidgetFactory::inputObject( QObject **objects, int& numObjects,
QBrush(color, value.asPixmap()) );
break;
default:
- tqFatal( "Corrupt" );
+ qFatal( "Corrupt" );
}
in >> paletteTag;
}
@@ -1156,7 +1156,7 @@ QObject *QWidgetFactory::inputObject( QObject **objects, int& numObjects,
}
break;
default:
- tqFatal( "Corrupt" );
+ qFatal( "Corrupt" );
}
in >> objectTag;
metAttribute--;
@@ -1193,14 +1193,14 @@ QWidget *QWidgetFactory::createFromUibFile( QDataStream& in,
in >> lf;
in >> cr;
if ( lf != '\n' || cr != '\r' ) {
- tqWarning( "File corrupted" );
+ qWarning( "File corrupted" );
return 0;
}
Q_UINT8 qdatastreamVersion;
in >> qdatastreamVersion;
if ( (int) qdatastreamVersion > in.version() ) {
- tqWarning( "Incompatible version of Qt" );
+ qWarning( "Incompatible version of Qt" );
return 0;
}
in.setVersion( qdatastreamVersion );
@@ -1259,7 +1259,7 @@ QWidget *QWidgetFactory::createFromUibFile( QDataStream& in,
unpackStringSplit( strings, in, slot );
// ###
#if 0
- tqWarning( "connect( %p, %s, %p, %s )", objects[senderNo],
+ qWarning( "connect( %p, %s, %p, %s )", objects[senderNo],
signal.latin1(), objects[receiverNo],
slot.latin1() );
#endif
@@ -1268,7 +1268,7 @@ QWidget *QWidgetFactory::createFromUibFile( QDataStream& in,
break;
case Block_Functions:
// ###
- tqWarning( "Block_Functions not supported" );
+ qWarning( "Block_Functions not supported" );
in.device()->at( nextBlock );
break;
case Block_Images:
@@ -1350,7 +1350,7 @@ QWidget *QWidgetFactory::createFromUibFile( QDataStream& in,
break;
case Block_Variables:
// ###
- tqWarning( "Block_Variables not supported" );
+ qWarning( "Block_Variables not supported" );
in.device()->at( nextBlock );
break;
case Block_Widget:
@@ -1361,7 +1361,7 @@ QWidget *QWidgetFactory::createFromUibFile( QDataStream& in,
toplevel->setName( name );
break;
default:
- tqWarning( "Version error" );
+ qWarning( "Version error" );
return 0;
}
in >> blockType;
@@ -1640,7 +1640,7 @@ QWidget *QWidgetFactory::createWidgetInternal( const QDomElement &e, QWidget *pa
QString parentClassName = parent ? parent->className() : 0;
bool isPlugin = parent ? !!d->customWidgets.find( parent->className() ) : FALSE;
if ( isPlugin )
- tqWarning( "####### loading custom container widgets without page support not implemented!" );
+ qWarning( "####### loading custom container widgets without page support not implemented!" );
// ### TODO loading for custom container widgets without pages
#endif
diff --git a/tools/linguist/linguist/trwindow.cpp b/tools/linguist/linguist/trwindow.cpp
index 40d71a6..e8725e5 100644
--- a/tools/linguist/linguist/trwindow.cpp
+++ b/tools/linguist/linguist/trwindow.cpp
@@ -769,7 +769,7 @@ void TrWindow::newPhraseBook()
void TrWindow::openPhraseBook()
{
- QString phrasebooks( tqInstallPathData() );
+ QString phrasebooks( qInstallPathData() );
QString name = QFileDialog::getOpenFileName( phrasebooks + "/phrasebooks",
tr("Qt phrase books (*.qph)\n"
"All files (*)"),
@@ -852,8 +852,8 @@ void TrWindow::revertSorting()
void TrWindow::manual()
{
- QAssistantClient *ac = new QAssistantClient( tqInstallPathBins(), this );
- ac->showPage( QString( tqInstallPathDocs() ) + "/html/linguist-manual.html" );
+ QAssistantClient *ac = new QAssistantClient( qInstallPathBins(), this );
+ ac->showPage( QString( qInstallPathDocs() ) + "/html/linguist-manual.html" );
}
void TrWindow::about()
diff --git a/tools/linguist/lupdate/fetchtr.cpp b/tools/linguist/lupdate/fetchtr.cpp
index 41314c0..ce8fb98 100644
--- a/tools/linguist/lupdate/fetchtr.cpp
+++ b/tools/linguist/lupdate/fetchtr.cpp
@@ -176,7 +176,7 @@ static int getToken()
break;
case 'T':
// TR() for when all else fails
- if ( tqstricmp(yyIdent + 1, "R") == 0 )
+ if ( qstricmp(yyIdent + 1, "R") == 0 )
return Tok_tr;
break;
case 'c':
@@ -350,7 +350,7 @@ static int getToken()
yyString[yyStringLen] = '\0';
if ( yyCh != '"' )
- tqWarning( "%s:%d: Unterminated C++ string",
+ qWarning( "%s:%d: Unterminated C++ string",
(const char *) yyFileName, yyLineNo );
if ( yyCh == EOF ) {
@@ -551,7 +551,7 @@ static void parse( MetaTranslator *tor, const char *initialContext,
QString::null, utf8) );
if ( lacks_Q_OBJECT.contains(context) ) {
- tqWarning( "%s:%d: Class '%s' lacks Q_OBJECT macro",
+ qWarning( "%s:%d: Class '%s' lacks Q_OBJECT macro",
(const char *) yyFileName, yyLineNo,
(const char *) context );
lacks_Q_OBJECT.remove( context );
@@ -622,7 +622,7 @@ static void parse( MetaTranslator *tor, const char *initialContext,
case Tok_Arrow:
yyTok = getToken();
if ( yyTok == Tok_tr || yyTok == Tok_trUtf8 )
- tqWarning( "%s:%d: Cannot invoke tr() like this",
+ qWarning( "%s:%d: Cannot invoke tr() like this",
(const char *) yyFileName, yyLineNo );
break;
case Tok_Gulbrandsen:
@@ -639,7 +639,7 @@ static void parse( MetaTranslator *tor, const char *initialContext,
if ( yyBraceDepth == (int) namespaces.count() ) {
if ( missing_Q_OBJECT ) {
if ( needs_Q_OBJECT.contains(functionContext) ) {
- tqWarning( "%s:%d: Class '%s' lacks Q_OBJECT macro",
+ qWarning( "%s:%d: Class '%s' lacks Q_OBJECT macro",
(const char *) yyFileName, yyLineNo,
(const char *) functionContext );
} else {
diff --git a/tools/makeqpf/main.cpp b/tools/makeqpf/main.cpp
index 56b89e2..0dceee3 100644
--- a/tools/makeqpf/main.cpp
+++ b/tools/makeqpf/main.cpp
@@ -242,16 +242,16 @@ private slots:
static void usage()
{
- tqWarning("Usage: makeqpf [-A] [-f spec-file] [font ...]");
- tqWarning("");
- tqWarning(" Saves QPF font files by rendering and saving fonts.");
- tqWarning("");
- tqWarning(" -A = Render and save all fonts in fontdir");
- tqWarning(" -f = File of lines:");
- tqWarning(" fontname character-ranges");
- tqWarning(" eg.");
- tqWarning(" smoothtimes 0-ff,20a0-20af");
- tqWarning(" font = Font to render and save");
+ qWarning("Usage: makeqpf [-A] [-f spec-file] [font ...]");
+ qWarning("");
+ qWarning(" Saves QPF font files by rendering and saving fonts.");
+ qWarning("");
+ qWarning(" -A = Render and save all fonts in fontdir");
+ qWarning(" -f = File of lines:");
+ qWarning(" fontname character-ranges");
+ qWarning(" eg.");
+ qWarning(" smoothtimes 0-ff,20a0-20af");
+ qWarning(" font = Font to render and save");
}
int main(int argc, char** argv)
@@ -303,7 +303,7 @@ int main(int argc, char** argv)
m.save(family);
}
} else {
- tqWarning("Cannot open %s",specfile.latin1());
+ qWarning("Cannot open %s",specfile.latin1());
}
} else {
while (*argv)
diff --git a/tools/mergetr/mergetr.cpp b/tools/mergetr/mergetr.cpp
index 9096081..c286a84 100644
--- a/tools/mergetr/mergetr.cpp
+++ b/tools/mergetr/mergetr.cpp
@@ -186,7 +186,7 @@ void writecomment( QTextStream &str, const QString &s )
while ( idx < len ) {
int nl = s.find( '\n', idx );
if ( nl < 0 ) {
- tqWarning( "writecomment: string lacks newline" );
+ qWarning( "writecomment: string lacks newline" );
str << "# " << s.mid( idx ) << '\n';
return;
}
diff --git a/tools/msg2qm/msg2qm.cpp b/tools/msg2qm/msg2qm.cpp
index 8a1a0de..6ac8c36 100644
--- a/tools/msg2qm/msg2qm.cpp
+++ b/tools/msg2qm/msg2qm.cpp
@@ -110,7 +110,7 @@ void addTranslation( QTranslator* translator, const QString& msgid, const QStrin
scope = *defaultScope;
if (translator->contains( scope.ascii(), id.ascii() ) ) {
- tqWarning("Error: \"%s\" already in use", msgid.ascii() );
+ qWarning("Error: \"%s\" already in use", msgid.ascii() );
}
else {
translator->insert( scope.latin1(), id.latin1(), msgstr );
diff --git a/tools/qconfig/main.cpp b/tools/qconfig/main.cpp
index fbcfb0b..f906fea 100644
--- a/tools/qconfig/main.cpp
+++ b/tools/qconfig/main.cpp
@@ -422,7 +422,7 @@ void Main::loadFeatures(const QString& filename)
sectioncontents[sec].append(feature);
choices.append(feature);
} else {
- tqDebug("Unparsed text");
+ qDebug("Unparsed text");
}
feature = lab = sec = QString::null;
@@ -439,7 +439,7 @@ void Main::loadFeatures(const QString& filename)
int colon = line.find(':');
if ( colon < 0 ) {
- tqDebug("Cannot parse: %s",line.ascii());
+ qDebug("Cannot parse: %s",line.ascii());
} else {
QString tag = line.left(colon);
QString value = line.mid(colon+1).stripWhiteSpace();
@@ -513,7 +513,7 @@ void Main::loadFeatures(const QString& filename)
deps.clear();
} else if ( token[0].isEmpty() ) {
} else {
- tqDebug("Cannot parse: %s",token.join(" ").ascii());
+ qDebug("Cannot parse: %s",token.join(" ").ascii());
}
} else if ( token[0] == "#include" ) {
on = TRUE;
@@ -545,7 +545,7 @@ void Main::createItem(const QString& ch)
for (QStringList::Iterator dp = deps.begin(); dp != deps.end(); ++dp) {
QString dsec = section[*dp];
if ( dsec.isEmpty() )
- tqDebug("No section for %s",(*dp).latin1());
+ qDebug("No section for %s",(*dp).latin1());
if ( !parent && dsec == sec ) {
createItem(*dp);
parent = item[*dp];
@@ -582,7 +582,7 @@ void Main::loadConfig(const QString& filename)
if ( i )
i->setDefined(TRUE);
else
- tqDebug("The item %s is not used by qfeatures.h", token[1].latin1());
+ qDebug("The item %s is not used by qfeatures.h", token[1].latin1());
}
} while (!s.atEnd());
}
@@ -608,14 +608,14 @@ void Main::updateAvailability(QListViewItem* i)
if ( dd->isDefined() || !dd->isAvailable() )
av = FALSE;
} else
- tqDebug("%s ???",(*dit).latin1());
+ qDebug("%s ???",(*dit).latin1());
}
if ( d->isAvailable() != av ) {
d->setAvailable(av);
updateAvailability(d);
}
}
-tqDebug("%s: %d",choice->id.latin1(),choice->isAvailable());
+qDebug("%s: %d",choice->id.latin1(),choice->isAvailable());
}
}
diff --git a/tools/qembed/qembed.cpp b/tools/qembed/qembed.cpp
index 8bcff7c..db0a87d 100644
--- a/tools/qembed/qembed.cpp
+++ b/tools/qembed/qembed.cpp
@@ -55,7 +55,7 @@ struct EmbedImage {
int main( int argc, char **argv )
{
if ( argc < 2 ) {
- tqWarning( "Usage:\n\t%s [--images] files", argv[0] );
+ qWarning( "Usage:\n\t%s [--images] files", argv[0] );
return 1;
}
@@ -103,19 +103,19 @@ int main( int argc, char **argv )
} else {
QFile f( *it );
if ( !f.open(IO_ReadOnly) ) {
- tqWarning( "Cannot open file %s, ignoring it", (*it).latin1() );
+ qWarning( "Cannot open file %s, ignoring it", (*it).latin1() );
continue;
}
QByteArray a( f.size() );
if ( f.size() == 0
|| f.readBlock(a.data(), f.size()) != (int)f.size() ) {
- tqWarning( "Cannot read file %s, ignoring it", (*it).latin1() );
+ qWarning( "Cannot read file %s, ignoring it", (*it).latin1() );
continue;
}
if ( images ) {
QImage img;
if ( !img.loadFromData(a) ) {
- tqWarning( "Cannot read image from file %s, ignoring it", (*it).latin1() );
+ qWarning( "Cannot read image from file %s, ignoring it", (*it).latin1() );
continue;
}
EmbedImage *e = new EmbedImage;
diff --git a/tools/qvfb/main.cpp b/tools/qvfb/main.cpp
index 0fea3b3..50e11ec 100644
--- a/tools/qvfb/main.cpp
+++ b/tools/qvfb/main.cpp
@@ -86,7 +86,7 @@ int main( int argc, char *argv[] )
displayId = displaySpec.mid( m+1, rx.matchedLength()-1 ).toInt();
}
- tqDebug( "Using display %d", displayId );
+ qDebug( "Using display %d", displayId );
QVFb mw( displayId, width, height, depth, skin );
app.setMainWidget( &mw );
diff --git a/tools/qvfb/qanimationwriter.cpp b/tools/qvfb/qanimationwriter.cpp
index 400d9da..35d6131 100644
--- a/tools/qvfb/qanimationwriter.cpp
+++ b/tools/qvfb/qanimationwriter.cpp
@@ -251,7 +251,7 @@ public:
QAnimationWriter::QAnimationWriter( const QString& filename, const char* format )
{
if ( QCString(format) != "MNG" ) {
- tqWarning("Format \"%s\" not supported, only MNG", format);
+ qWarning("Format \"%s\" not supported, only MNG", format);
dev = 0;
d = 0;
} else {
@@ -389,7 +389,7 @@ void QAnimationWriter::appendFrame(const QImage& frm, const QPoint& offset)
}
}
}
-tqDebug("%d,%d %d,%d",minx,miny,offset.x(),offset.y());
+qDebug("%d,%d %d,%d",minx,miny,offset.x(),offset.y());
d->composeImage(diff,QPoint(minx,miny)+offset);
}
if ( prev.isNull() || prev.size() == frame.size() && offset == QPoint(0,0) ) {
diff --git a/tools/qvfb/qvfbview.cpp b/tools/qvfb/qvfbview.cpp
index 2c1422d..781cf78 100644
--- a/tools/qvfb/qvfbview.cpp
+++ b/tools/qvfb/qvfbview.cpp
@@ -88,7 +88,7 @@ QVFbView::QVFbView( int display_id, int w, int h, int d, QWidget *parent,
break;
default:
- tqFatal( "Unsupported bit depth %d\n", d );
+ qFatal( "Unsupported bit depth %d\n", d );
}
mousePipe = QString(QT_VFB_MOUSE_PIPE).arg(display_id);
@@ -99,14 +99,14 @@ QVFbView::QVFbView( int display_id, int w, int h, int d, QWidget *parent,
mouseFd = open( mousePipe.latin1(), O_RDWR | O_NDELAY );
if ( mouseFd == -1 ) {
- tqFatal( "Cannot open mouse pipe" );
+ qFatal( "Cannot open mouse pipe" );
}
unlink( keyboardPipe );
mkfifo( keyboardPipe, 0666 );
keyboardFd = open( keyboardPipe, O_RDWR | O_NDELAY );
if ( keyboardFd == -1 ) {
- tqFatal( "Cannot open keyboard pipe" );
+ qFatal( "Cannot open keyboard pipe" );
}
key_t key = ftok( mousePipe.latin1(), 'b' );
@@ -129,7 +129,7 @@ QVFbView::QVFbView( int display_id, int w, int h, int d, QWidget *parent,
}
if ( (long)data == -1 )
- tqFatal( "Cannot attach to shared memory" );
+ qFatal( "Cannot attach to shared memory" );
hdr = (QVFbHeader *)data;
hdr->width = w;
@@ -215,7 +215,7 @@ void QVFbView::setGamma(double gr, double gg, double gb)
if ( g > 255 ) g = 255;
if ( b > 255 ) b = 255;
gammatable[i] = qRgb(r,g,b);
-//tqDebug("%d: %d,%d,%d",i,r,g,b);
+//qDebug("%d: %d,%d,%d",i,r,g,b);
}
setDirty(rect());
@@ -282,25 +282,25 @@ static QString qws_dataDir()
QString dataDir = "/tmp/qtembedded-" + username;
if ( mkdir( dataDir.latin1(), 0700 ) ) {
if ( errno != EEXIST ) {
- tqFatal( QString("Cannot create Qt/Embedded data directory: %1")
+ qFatal( QString("Cannot create Qt/Embedded data directory: %1")
.arg( dataDir ) );
}
}
struct stat buf;
if ( lstat( dataDir.latin1(), &buf ) )
- tqFatal( QString( "stat failed for Qt/Embedded data directory: %1" )
+ qFatal( QString( "stat failed for Qt/Embedded data directory: %1" )
.arg( dataDir ) );
if ( !S_ISDIR( buf.st_mode ) )
- tqFatal( QString( "%1 is not a directory" ).arg( dataDir ) );
+ qFatal( QString( "%1 is not a directory" ).arg( dataDir ) );
if ( buf.st_uid != getuid() )
- tqFatal( QString( "Qt/Embedded data directory is not owned by user %1" )
+ qFatal( QString( "Qt/Embedded data directory is not owned by user %1" )
.arg( getuid() ) );
if ( (buf.st_mode & 0677) != 0600 )
- tqFatal( QString( "Qt/Embedded data directory has incorrect permissions: %1" )
+ qFatal( QString( "Qt/Embedded data directory has incorrect permissions: %1" )
.arg( dataDir ) );
dataDir += "/";
@@ -485,7 +485,7 @@ void QVFbView::drawScreen()
QRect r( hdr->update );
hdr->dirty = FALSE;
hdr->update = QRect();
- // tqDebug( "update %d, %d, %dx%d", r.y(), r.x(), r.width(), r.height() );
+ // qDebug( "update %d, %d, %dx%d", r.y(), r.x(), r.width(), r.height() );
r = r.intersect( QRect(0, 0, hdr->width, hdr->height ) );
if ( !r.isEmpty() ) {
if ( int(zm) != zm ) {
diff --git a/tools/designer/designer/resource.cpp b/tools/designer/designer/resource.cpp
index cb1c39a..257f4e6 100644
--- a/tools/designer/designer/resource.cpp
+++ b/tools/designer/designer/resource.cpp
@@ -1756,7 +1756,7 @@ void Resource::saveProperty( QObject *w, const QString &name, const QVariant &va
break;
}
default:
- tqWarning( "saving the property %s of type %d not supported yet", name.latin1(), (int)t );
+ qWarning( "saving the property %s of type %d not supported yet", name.latin1(), (int)t );
}
}
@@ -1803,7 +1803,7 @@ QObject *Resource::createObject( const QDomElement &e, QWidget *parent, QLayout*
bool isPlugin =
WidgetDatabase::isCustomPluginWidget( WidgetDatabase::idFromClassName( parentClassName ) );
if ( isPlugin )
- tqWarning( "####### loading custom container widgets without page support not implemented!" );
+ qWarning( "####### loading custom container widgets without page support not implemented!" );
// ### TODO loading for custom container widgets without pages
#endif
if ( !className.isNull() ) {
@@ -2367,9 +2367,9 @@ void Resource::saveImageData( const QImage &img, QTextStream &ts, int indent )
QByteArray bazip = ba;
int i = 0;
if (compress) {
- bazip = tqCompress( ba );
+ bazip = qCompress( ba );
format += ".GZ";
// The first 4 bytes in tqCompress() are the length of the unzipped
// format. The XPM.GZ format does not use these.
i = 4;
}
@@ -2367,9 +2367,9 @@ void Resource::saveImageData( const QImage &img, QTextStream &ts, int indent )
format += ".GZ";
- // The first 4 bytes in tqCompress() are the length of the unzipped
+ // The first 4 bytes in qCompress() are the length of the unzipped
// format. The XPM.GZ format does not use these.
i = 4;
diff --git a/tools/designer/plugins/cppeditor/yyreg.cpp b/tools/designer/plugins/cppeditor/yyreg.cpp
index 0648e36..144c99f 100644
--- a/tools/designer/plugins/cppeditor/yyreg.cpp
+++ b/tools/designer/plugins/cppeditor/yyreg.cpp
@@ -71,7 +71,7 @@ enum { Tok_Boi, Tok_Ampersand, Tok_Aster, Tok_LeftParen, Tok_RightParen,
/*
The following variables store the lexical analyzer state. The best way
to understand them is to implement a function myGetToken() that calls
- getToken(), to add some tqDebug() statements in there and then to
+ getToken(), to add some qDebug() statements in there and then to
#define getToken() myGetToken().
*/
static QString *yyIn; // the input stream
@@ -143,7 +143,7 @@ static void stopTokenizer()
*/
static int getToken()
{
// why "+ 2"? try putting some tqDebug()'s and see
yyPos = yyCurPos + 2;
for ( ;; ) {
@@ -177,7 +177,7 @@ static int getToken()
around with the tokenizer state to effectively
ignore the comment. Beware of off-by-one and
off-by-two bugs when you modify this code by adding
- tqDebug()'s here and there.
+ qDebug()'s here and there.
*/
if ( yyCurPos >= 0 ) {
int lineStart = yyIn->findRev( QChar('\n'), yyCurPos ) + 1;
@@ -143,7 +143,7 @@ static void stopTokenizer()
static int getToken()
{
- // why "+ 2"? try putting some tqDebug()'s and see
+ // why "+ 2"? try putting some qDebug()'s and see
yyPos = yyCurPos + 2;
for ( ;; ) {